@@ -10,8 +10,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/bin',
- 'BINLIBDEST': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
+ 'BINDIR': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/bin',
+ 'BINLIBDEST': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
  'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': 'clang -bundle -undefined dynamic_lookup -arch x86_64 '
               '-Wl,-search_paths_first -arch x86_64 -Wl,-search_paths_first',
@@ -45,34 +45,34 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-DNDEBUG -arch x86_64',
  'CONFIGURE_LDFLAGS': '-arch x86_64 -Wl,-search_paths_first',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit' "
-                "'--enable-shared' '--with-ensurepip' "
+ 'CONFIG_ARGS': "'--prefix=/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit' "
+                "'--enable-shared' '--with-ensurepip=install' "
+                "'--with-openssl=/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit' "
                 "'CFLAGS=-I/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/usr/include "
                 '-O2 -g -arch x86_64 -fno-common '
                 '-Werror=unguarded-availability-new '
-                "-mmacosx-version-min=10.15' "
-                "'--with-openssl=/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit' "
-                "'ac_cv_header_libintl_h=no' 'ac_cv_lib_intl_textdomain=no' "
+                "-mmacosx-version-min=10.15' 'ac_cv_header_libintl_h=no' "
+                "'ac_cv_lib_intl_textdomain=no' "
                 "'ac_cv_pthread_system_supported=yes' 'ac_cv_func_preadv=no' "
                 "'ac_cv_func_pwritev=no' 'CC=clang' 'LDFLAGS=-arch x86_64 "
                 "-Wl,-search_paths_first' 'CPPFLAGS=-DNDEBUG -arch x86_64' "
-                "'PKG_CONFIG_PATH=/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib64/pkgconfig:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib/pkgconfig'",
- 'CONFINCLUDEDIR': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include',
- 'CONFINCLUDEPY': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9',
+                "'PKG_CONFIG_PATH=/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/lib64/pkgconfig:/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/lib/pkgconfig'",
+ 'CONFINCLUDEDIR': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include',
+ 'CONFINCLUDEPY': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5/coverage.info',
- 'COVERAGE_REPORT': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5/lcov-report',
+ 'COVERAGE_INFO': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5/coverage.info',
+ 'COVERAGE_REPORT': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -DNDEBUG -arch x86_64 -DNDEBUG -arch x86_64',
  'CXX': 'clang++',
- 'DESTDIRS': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit '
-             '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib '
-             '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9 '
-             '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9/lib-dynload',
- 'DESTLIB': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
+ 'DESTDIRS': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit '
+             '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib '
+             '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9 '
+             '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -91,7 +91,7 @@ build_time_vars = {'ABIFLAGS': '',
  'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'upgrade',
+ 'ENSUREPIP': 'install',
  'EXE': '',
  'EXEMODE': 755,
  'EXPORTSFROM': '',
@@ -531,12 +531,12 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-apple-darwin20.3.0',
- 'INCLDIRSTOMAKE': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include '
-                   '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include '
-                   '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9 '
-                   '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9',
- 'INCLUDEDIR': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include',
- 'INCLUDEPY': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9',
+ 'INCLDIRSTOMAKE': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include '
+                   '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include '
+                   '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9 '
+                   '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9',
+ 'INCLUDEDIR': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include',
+ 'INCLUDEPY': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
@@ -555,14 +555,14 @@ build_time_vars = {'ABIFLAGS': '',
              '-Wl,-search_paths_first -arch x86_64 -Wl,-search_paths_first',
  'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
- 'LIBDIR': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib',
+ 'LIBDEST': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
+ 'LIBDIR': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/pkgconfig',
- 'LIBPL': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9/config-3.9-darwin',
+ 'LIBPC': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/pkgconfig',
+ 'LIBPL': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9/config-3.9-darwin',
  'LIBPYTHON': '',
  'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
@@ -581,13 +581,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'darwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
+ 'MACHDESTLIB': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '10.15',
  'MAINCC': 'clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/share/man',
+ 'MANDIR': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/share/man',
  'MKDIR_P': './install-sh -c -d',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
@@ -613,8 +613,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/include',
- 'OPENSSL_LDFLAGS': '-L/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib',
+ 'OPENSSL_INCLUDES': '-I/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/include',
+ 'OPENSSL_LDFLAGS': '-L/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
@@ -722,8 +722,8 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_LIBRARY_PATH=/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/sqlite-3.32.3-shell-macos11-x86-64bit/lib:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib64:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib',
- 'SCRIPTDIR': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/lib',
+ 'RUNSHARED': 'DYLD_LIBRARY_PATH=/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5:/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/lib',
+ 'SCRIPTDIR': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
@@ -764,10 +764,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_LIBRARY_PATH=/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/sqlite-3.32.3-shell-macos11-x86-64bit/lib:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib64:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib '
+ 'TESTPYTHON': 'DYLD_LIBRARY_PATH=/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5:/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/lib '
                './python.exe',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_LIBRARY_PATH=/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/sqlite-3.32.3-shell-macos11-x86-64bit/lib:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib64:/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/openssl-1.1.1l-macos11-x86-64bit/lib '
+ 'TESTRUNNER': 'DYLD_LIBRARY_PATH=/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5:/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/openssl-1.1.1l-macos11-x86-64bit/lib '
                './python.exe ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -776,7 +776,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.9 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 1,
@@ -790,9 +790,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5',
- 'abs_srcdir': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-export-1212627/Python-3.9.5',
- 'datarootdir': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit/share',
- 'exec_prefix': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit',
- 'prefix': '/Volumes/hd2/pb2/build/sb_0-4580984-1632452592.97/Python-3.9.5-shell-macos11-x86-64bit',
+ 'abs_builddir': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5',
+ 'abs_srcdir': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-export-1444150/Python-3.9.5',
+ 'datarootdir': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit/share',
+ 'exec_prefix': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit',
+ 'prefix': '/Volumes/hd2/pb2/build/sb_0-5451091-1639112787.79/Python-3.9.5-shell-macos11-x86-64bit',
  'srcdir': '.'}
